@@ -351,7 +351,7 @@ class MainWgt(QtGui.QMainWindow):
             pass
 
     def setScrollBarVal(self):
-        self.main_frame.verticalScrollBar().setValue \
+        self.main_frame.verticalScrollBar().setSliderPosition \
                                 (self.main_frame.verticalScrollBar().maximum())
 
     def signaling_slot(self, sid, reply):
