@@ -110,7 +110,7 @@ class ApiClient(QtGui.QWidget):
                 self.lang = gettext.locale.getdefaultlocale()[0][:2]
                 lang = gettext.translation('cl_consolegui3', \
                                            languages=[self.lang])
-            except IOError:
+            except (TypeError,IOError) as e:
                 self.lang = 'en'
                 lang = gettext.translation('cl_consolegui3',fallback=True)
 
