@@ -89,8 +89,8 @@ class AddServerCert (QtGui.QDialog):
         self.grid.addWidget(self.tab, 3, 0, 3, 3)
 
         self.lbl_list.append(LabelWordWrap \
-                 (_("Add this server's certificate to trusted or ") +\
-                 _('try add the CA and ROOT certificates to trusted?'),self))
+                 (_("Add this server certificate to trusted or ") +\
+                 _('try adding the CA and root certificates to trusted?'),self))
 
         self.pix_lbl = QtGui.QLabel(self)
         pi = QtGui.QPixmap()
@@ -108,7 +108,7 @@ class AddServerCert (QtGui.QDialog):
         self.server_but.clicked.connect(self.close)
         self.grid.addWidget(self.server_but, x, 0)
 
-        self.ca_but = QtGui.QPushButton(_('Add the CA and ROOT certificates'),
+        self.ca_but = QtGui.QPushButton(_("Add the CA and root certificates"),
                                         self)
         self.ca_but.clicked.connect(self.add_ca)
         self.ca_but.clicked.connect(self.add_server)
@@ -174,7 +174,8 @@ class AddServerCert (QtGui.QDialog):
         self.ConnectWidget.connect_to_host(host, self.ClientObj.port)
 
     def add_ca(self):
-        cl_client_cert_dir = self.ClientObj.VarsApi.Get('cl_client_cert_dir')
+        cl_client_cert_dir = \
+            self.ClientObj.VarsApi.Get('core.cl_client_cert_dir')
         homePath = self.ClientObj.VarsApi.Get('ur_home_path')
         cl_client_cert_dir = cl_client_cert_dir.replace("~",homePath)
         root_cert_dir = cl_client_cert_dir + "/ca"
@@ -227,7 +228,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
             self.sock = sock
             self._tunnel()
 
-        user_root_cert = self.ClientObj.VarsApi.Get('cl_user_root_cert')
+        user_root_cert = self.ClientObj.VarsApi.Get('core.cl_user_root_cert')
         homePath = self.ClientObj.VarsApi.Get('ur_home_path')
         user_root_cert = user_root_cert.replace("~",homePath)
         result_user_root = 1
@@ -238,7 +239,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                                               user_root_cert, self.CRL_PATH)
             if result_user_root == 1:
                 glob_root_cert = self.ClientObj.VarsApi.Get \
-                                                      ('cl_glob_root_cert')
+                                                      ('core.cl_glob_root_cert')
                 result_root_con = 1
                 if os.path.exists(glob_root_cert):
                     sock = socket.create_connection((self.host, self.port),
@@ -314,19 +315,22 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
     def add_all_ca_cert(self, list_ca_certs):
         # so root cert be first, ca after
         homePath = self.ClientObj.VarsApi.Get('ur_home_path') 
-        cl_client_cert_dir = self.ClientObj.VarsApi.Get('cl_client_cert_dir')
+        cl_client_cert_dir = \
+            self.ClientObj.VarsApi.Get('core.cl_client_cert_dir')
 
         cl_client_cert_dir = cl_client_cert_dir.replace("~",homePath)
         root_cert_md5 = cl_client_cert_dir + "/ca/cert_list"
 
         list_ca_certs.reverse()
         for cert in list_ca_certs:
-            system_ca_db = self.ClientObj.VarsApi.Get('cl_glob_root_cert')
+            system_ca_db = \
+                self.ClientObj.VarsApi.Get('core.cl_glob_root_cert')
             if os.path.exists(system_ca_db):
                 if cert in open(system_ca_db, 'r').read():
                     continue
 
-            user_root_cert = self.ClientObj.VarsApi.Get('cl_user_root_cert')
+            user_root_cert = \
+                self.ClientObj.VarsApi.Get('core.cl_user_root_cert')
             user_root_cert = user_root_cert.replace("~",homePath)
             if os.path.exists(user_root_cert):
                 if cert in open(user_root_cert, 'r').read():
@@ -390,7 +394,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
             cert = '0'
 
         if cert == '1':
-            msg = _('Invalid server certificate')
+            msg = _("Invalid server certificate!")
             show_msg (msg)
             return
 
@@ -643,11 +647,11 @@ def get_CRL(path_to_cert):
     clVars.importCore()
     clVars.flIniFile()
     # user and system  ca and root certificates
-    user_root_cert = clVars.Get('cl_user_root_cert')
+    user_root_cert = clVars.Get('core.cl_user_root_cert')
     homePath = clVars.Get('ur_home_path')
     user_root_cert = user_root_cert.replace("~",homePath)
 
-    glob_root_cert = clVars.Get('cl_glob_root_cert')
+    glob_root_cert = clVars.Get('core.cl_glob_root_cert')
 
     if os.path.exists(user_root_cert):
         user_ca_certs = open(user_root_cert, 'r').read()
@@ -748,12 +752,12 @@ def rm_ca_from_trusted(ca_cert):
     clVars.importCore()
     clVars.flIniFile()
 
-    user_ca_dir = clVars.Get('cl_client_cert_dir')
+    user_ca_dir = clVars.Get('core.cl_client_cert_dir')
     homePath = clVars.Get('ur_home_path')
     user_ca_dir = user_ca_dir.replace("~",homePath)
     user_ca_dir = os.path.join(user_ca_dir, 'ca')
     user_ca_list = os.path.join(user_ca_dir, 'cert_list')
-    user_ca_db = clVars.Get('cl_user_root_cert')
+    user_ca_db = clVars.Get('core.cl_user_root_cert')
     homePath = clVars.Get('ur_home_path')
     user_ca_db = user_ca_db.replace("~",homePath)
 
