@@ -23,7 +23,6 @@ class DataVarsGui(DataVars):
     """Variable class for installation"""
 
     def importGui(self, **args):
-        '''Заполнить конфигурацию переменных, для десктопа'''
-        self.importData()
-        self.importData('calculate.core.variables')
-        self.importData('calculate.consolegui.variables')
+        self.importVariables()
+        self.importVariables('calculate.consolegui.variables')
+        self.defaultModule = "consolegui"
