@@ -18,7 +18,7 @@ import sys
 from os import path
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_gui',sys.modules[__name__])
+setLocalTranslate('cl_consolegui3',sys.modules[__name__])
 
 class VariableClGuiData(Variable):
     """
@@ -43,4 +43,4 @@ class VariableClGuiConfigPath(Variable):
     """
     Variable store path to config file
     """
-    value = '~/.calculate/console_gui/console_gui.conf'
\ No newline at end of file
+    value = '~/.calculate/console_gui/console_gui.conf'
